CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
51 lines
1.4 KiB
C++
51 lines
1.4 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
|
|
#define LEN 512
|
|
#define SIZE LEN << 2
|
|
|
|
__global__ void floatMath(float* In, float* Out) {
|
|
int tid = threadIdx.x + blockIdx.x * blockDim.x;
|
|
Out[tid] = __cosf(In[tid]);
|
|
Out[tid] = __exp10f(Out[tid]);
|
|
Out[tid] = __expf(Out[tid]);
|
|
Out[tid] = __frsqrt_rn(Out[tid]);
|
|
#if defined OCML_BASIC_ROUNDED_OPERATIONS
|
|
Out[tid] = __fsqrt_rd(Out[tid]);
|
|
#endif
|
|
Out[tid] = __fsqrt_rn(Out[tid]);
|
|
#if defined OCML_BASIC_ROUNDED_OPERATIONS
|
|
Out[tid] = __fsqrt_ru(Out[tid]);
|
|
Out[tid] = __fsqrt_rz(Out[tid]);
|
|
#endif
|
|
Out[tid] = __log10f(Out[tid]);
|
|
Out[tid] = __log2f(Out[tid]);
|
|
Out[tid] = __logf(Out[tid]);
|
|
Out[tid] = __powf(2.0f, Out[tid]);
|
|
__sincosf(Out[tid], &In[tid], &Out[tid]);
|
|
Out[tid] = __sinf(Out[tid]);
|
|
Out[tid] = __cosf(Out[tid]);
|
|
Out[tid] = __tanf(Out[tid]);
|
|
}
|
|
|
|
HIP_TEST_CASE(Unit_deviceFunctions_CompileTest) {
|
|
float *Ind, *Outd;
|
|
auto res = hipMalloc((void**)&Ind, SIZE);
|
|
REQUIRE(res == hipSuccess);
|
|
res = hipMalloc((void**)&Outd, SIZE);
|
|
REQUIRE(res == hipSuccess);
|
|
hipLaunchKernelGGL(floatMath, dim3(LEN, 1, 1), dim3(1, 1, 1), 0, 0, Ind, Outd);
|
|
HIP_CHECK(hipGetLastError());
|
|
res = hipDeviceSynchronize();
|
|
REQUIRE(res == hipSuccess);
|
|
res = hipGetLastError();
|
|
REQUIRE(res == hipSuccess);
|
|
HIP_CHECK(hipFree(Ind));
|
|
HIP_CHECK(hipFree(Outd));
|
|
}
|